# Odak noktası

`fixation_dot` eklentisi kolay bir eklentidir. Bu eklenti `sketchpad` ögesinin yapabileceklerinden daha fazlasını sunmaz. Ancak bu eklenti sadece odak noktası (fixation dot) göstermek istedğinizde kullanışlıdır.

Aşağıdaki seçenekleri kullanabilirsiniz:

- `Style` odak noktasının stilini belirler.
- `Duration` pozitif bir sayı, 'tuşa basım' (keypress) ya da 'fare tıklaması' (mouseclick) olarak girilmelidir. Girdiye göre odak noktası belirlenen süre kadar bir tuşa basılana kadar ya da fare tıklanana kadar ekranda görünür.
- `Foreground color` İngilizce bir renk adı (örneğin, 'blue') ya da HTML renk değeri olarak (e.g., '#0000FF') girilmelir.
- `Background color` İngilizce bir renk adı (örneğin, 'blue') ya da HTML renk değeri olarak (e.g., '#0000FF') girilmelir.
- `X` ve `Y` koordinatları odak noktasının pozisyonunu belirler.
